@@ -1,4 +1,4 @@
 class PyVnfmSdkException(Exception):
-    def __init__(self, *args, vnfr=None):
+    def __init__(self, vnfr=None, *args):
         super(PyVnfmSdkException, self).__init__(*args)
         self.vnfr = vnfr
